import { Checkbox, FormHelperText, IconButton, TableCell, Tooltip, Typography, } from "@material-ui/core";
import FileCopyIcon from "@material-ui/icons/FileCopy";
import { debounce } from "lodash";
import { useSnackbar } from "notistack";
import React, { useCallback, useMemo, useState } from "react";
import { formatDate } from "../../../helpers/formatDate";
import { getNumberFormat } from "../../../helpers/getNumberFormat";
import { FormatDate } from "../FormatField/FormatDate";
import { FormatNumber } from "../FormatField/FormatNumber";
import { useTableRowStyles } from "../TableRow/styles";
import { TableColumnAlign } from "../types";
import { useTableRenderCellStyles } from "./styles";
export const TableRenderCell = ({ column, row, editMode, }) => {
    const classes = useTableRowStyles();
    const renderCellClasses = useTableRenderCellStyles();
    const [isShown, setIsShown] = useState(false);
    const { enqueueSnackbar } = useSnackbar();
    const additionalCellProps = column.additionalCellProps &&
        typeof column.additionalCellProps === "function"
        ? column.additionalCellProps(row)
        : column.additionalCellProps;
    const displayCell = useCallback(() => {
        switch (column.type) {
            case "amount":
            case "amount-range":
                return (React.createElement(Typography, { className: row[column.field] < 0
                        ? renderCellClasses.negativeAmount
                        : "" },
                    React.createElement(FormatNumber, { value: row[column.field] })));
            case "date":
            case "date-range":
            case "date-time-range":
                return React.createElement(FormatDate, { value: row[column.field] });
            case "checkbox":
                return (React.createElement(Checkbox, { checked: !!row[column.field], disabled: true, className: classes.displayCheckbox }));
            default:
                return row[column.field];
        }
    }, [
        column.field,
        column.type,
        row,
        classes,
        renderCellClasses.negativeAmount,
    ]);
    const handleCopyClick = () => {
        const cell = displayCell();
        let cellText = "";
        if (typeof cell === "object" && "format" in (cell || {})) {
            cellText = cell.format;
        }
        else {
            switch (column.type) {
                case "date":
                case "date-range":
                    cellText = formatDate(row[column.field]);
                    break;
                case "amount":
                    cellText = getNumberFormat(row[column.field]);
                    break;
                case "checkbox":
                    cellText = (!!row[column.field]).toString();
                    break;
                default:
                    cellText = cell;
            }
        }
        navigator.clipboard.writeText(cellText);
        enqueueSnackbar("Copied to Clipboard", {
            variant: "success",
            autoHideDuration: 1000,
        });
    };
    // eslint-disable-next-line react-hooks/exhaustive-deps
    const debounceOpen = useCallback(debounce(() => setIsShown(!editMode && !!row[column.field]), 300), [setIsShown]);
    const TooltipDisplayContent = useMemo(() => column.type === "checkbox"
        ? (!!row[column.field]).toString()
        : displayCell(), [displayCell, column.type, column.field, row]);
    return (React.createElement(Tooltip, { classes: { tooltip: classes.copyTooltip, popper: classes.copyPopper }, title: React.createElement(Tooltip, { title: column.modifier
                ? column.modifier(row)
                : TooltipDisplayContent },
            React.createElement(IconButton, { size: "small", "aria-label": "copy-to-clipboard", className: classes.copyTooltipButton, color: "primary", onClick: (e) => {
                    e.stopPropagation();
                    handleCopyClick();
                } },
                React.createElement(FileCopyIcon, { fontSize: "small" }))), enterDelay: 1000, placement: "top-end", interactive: true, onOpen: debounceOpen, onClose: () => {
            debounceOpen.cancel();
            setIsShown(false);
        }, open: isShown },
        React.createElement(TableCell, Object.assign({}, (additionalCellProps || {}), { align: column.align || TableColumnAlign.LEFT, className: classes.slimmerRow }),
            column.modifier ? column.modifier(row) : displayCell(),
            editMode && React.createElement(FormHelperText, null))));
};
//# sourceMappingURL=TableRenderCell.js.map